@@ -192,40 +192,7 @@ void properties_apply_font_cb(StickyNote *note)
 void
 properties_color_cb (GtkWidget *button, StickyNote *note)
 {
-	char *color_str = NULL;
-	char *font_color_str = NULL;
-	
-	if (!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(note->w_def_color)))
-	{
-#if GTK_CHECK_VERSION (3, 0, 0)
-		GdkRGBA color, font_color;
-
-		gtk_color_button_get_rgba (GTK_COLOR_BUTTON (note->w_color), &color);
-		gtk_color_button_get_rgba (GTK_COLOR_BUTTON (note->w_font_color), &font_color);
-
-		color_str = gdk_rgba_to_string (&color);
-		font_color_str = gdk_rgba_to_string (&font_color);
-#else
-		GdkColor color, font_color;
-			
-		gtk_color_button_get_color (GTK_COLOR_BUTTON (note->w_color), &color);
-		gtk_color_button_get_color (GTK_COLOR_BUTTON (note->w_font_color), &font_color);
-
-		color_str = g_strdup_printf ("#%.2x%.2x%.2x",
-		                             color.red   / 256,
-		                             color.green / 256,
-		                             color.blue  / 256);
-		font_color_str = g_strdup_printf ("#%.2x%.2x%.2x",
-		                                  font_color.red   / 256,
-		                                  font_color.green / 256,
-		                                  font_color.blue  / 256);
-#endif
-	}
-
-	stickynote_set_color (note, color_str, font_color_str, TRUE);
-
-	g_free (color_str);
-	g_free (font_color_str);
+	properties_apply_color_cb (note);
 }
 
 /* Properties Dialog Callback : Font */
